Spatial Inequality  Analysis in PySAL
=====================================

![tag](https://img.shields.io/github/v/release/pysal/inequality?include_prereleases&sort=semver)
[![Continuous Integration](https://github.com/pysal/inequality/actions/workflows/testing.yml/badge.svg)](https://github.com/pysal/inequality/actions/workflows/testing.yml)
[![codecov](https://codecov.io/gh/pysal/inequality/branch/main/graph/badge.svg)](https://codecov.io/gh/pysal/inequality)
[![Documentation](https://img.shields.io/static/v1.svg?label=docs&message=current&color=9cf)](http://pysal.org/inequality/)

Methods for measuring spatial inequality.


Installation
------------

Install inequality from PyPI by running:

```
$ pip install inequality 
```

Install inequality from conda-forge by running:

```
$ conda install -c conda-forge inequality 
```

#### Requirements

- libpysal
- numpy
- scipy

Contribute
----------

PySAL-inequality is under active development and contributors are welcome.

If you have any suggestion, feature request, or bug report, please open a new [issue](https://github.com/pysal/inequality/issues) on GitHub. To submit patches, please follow the PySAL development [guidelines](http://pysal.org/docs/devs/) and open a [pull request](https://github.com/pysal/inequality). Once your changes get merged, you’ll automatically be added to the [Contributors List](https://github.com/pysal/inequality/graphs/contributors).

Support
-------

If you are having issues, please talk to us in the [gitter room](https://gitter.im/pysal/inequality).

License
-------

The project is licensed under the [BSD license](https://github.com/pysal/giddy/blob/main/LICENSE.txt).

Funding
-------

<img src="docs/_static/images/nsf_logo.jpg" width="50"> Award #1421935 [New Approaches to Spatial Distribution Dynamics](https://www.nsf.gov/awardsearch/showAward?AWD_ID=1421935)
